:mod:`xoutil.aop.classical` - Classical AOP
============================================

.. automodule:: xoutil.aop.classical
   :members: weave, _weave_after_method, _weave_before_method,
             _weave_around_method
   :undoc-members:
